PEG_PRECISION = 10 ** 3
FUNDING_PRECISION = 10 ** 4
QUOTE_PRECISION = 10 ** 6
MARK_PRICE_PRECISION = 10 ** 10
AMM_RESERVE_PRECISION = 10 ** 13

AMM_TO_QUOTE_PRECISION_RATIO = AMM_RESERVE_PRECISION / QUOTE_PRECISION  # 10**7
PRICE_TO_QUOTE_PRECISION = MARK_PRICE_PRECISION / QUOTE_PRECISION  # 10**7
AMM_TIMES_PEG_TO_QUOTE_PRECISION_RATIO = (
    AMM_RESERVE_PRECISION * PEG_PRECISION / QUOTE_PRECISION
)

FULL_LIQUIDATION_RATIO = 500
PARTIAL_LIQUIDATION_RATIO = 625

MAX_LEVERAGE = 5
